# Table of Contents

1.  [Welcome to ResearchHelper](#orga7ce240)
2.  [Sphinx, Pypi](#org6b44add)


<a id="orga7ce240"></a>

# Welcome to ResearchHelper

This is a personal repository of functions that I use throughout projects. Besides that, it could obviously also be useful to others! So see if it holds something for you.


<a id="org6b44add"></a>

# Sphinx, Pypi

This package is not only for my functionality, but also to practice in making a package and documenting is correctly. For that I'm using Sphinx. The online hosted documentation is found on my website <https://www.baschatel.nl/ResearchHelper>.
